[hide private]
[frames] | no frames]

[ Identifiers | To Do ]

# To Do List

To Do in camelot.camelot.view.elixir_admin rewrite docstring Admin classes, specify how objects should be rendered in the gui An admin class has class attributes like 'list_display' which contains the columns that should be displayed in a list view (again, see Django) So this 'list_display' attribute can be overwritten in the Admin class for each model. But for the gui generation itself, we don't use the class attributes, but we use methods, like 'getColumns', that way, we can make the gui very specific, on the context

To Do in camelot.camelot.view.model_thread.gui_function now it only checks if the function is not called within the model thread, this is incomplete